@@ -3,7 +3,7 @@
     :codeauthor: Jayesh Kariya <jayeshk@saltstack.com>
 '''
 # Import Python libs
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function, unicode_literals
 import os
 
 # Import Salt Testing Libs
@@ -95,7 +95,6 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                               side_effect=[None, True]):
                 with patch.object(solr, '_check_for_cores',
                                   side_effect=[True, False]):
-
                     tempdict = {'success': 'success', 'errors': 'errors',
                                 'warnings': 'warnings',
                                 'data': {'lucene': {'solr-spec-version': 1}}}
@@ -104,15 +103,13 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                         with patch.dict(solr.__salt__,
                                         {'config.option':
                                          MagicMock(return_value=['A'])}):
-                            with patch.object(solr, '_http_request',
-                                              return_value=tempdict):
+                            with patch.object(solr, '_http_request', return_value=tempdict):
                                 with patch.object(solr, '_update_return_dict',
                                                   return_value={'A': 'a'}):
                                     self.assertDictEqual(solr.optimize(),
                                                          {'A': 'a'})
 
-                        with patch.object(solr, '_http_request',
-                                                return_value='A'):
+                        with patch.object(solr, '_http_request', return_value='A'):
                             self.assertEqual(solr.optimize(), 'A')
 
     def test_ping(self):
@@ -140,7 +137,7 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                                 self.assertDictEqual(solr.ping(), {'A': 'a'})
 
                     with patch.object(solr, '_get_admin_info',
-                                            return_value='A'):
+                                      return_value='A'):
                         self.assertEqual(solr.ping(), 'A')
 
     def test_is_replication_enabled(self):
@@ -151,18 +148,11 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
         error = 'Only "slave" minions can run "is_replication_enabled"'
         with patch.object(solr, '_get_return_dict', return_value={'A': 'a'}):
             with patch.object(solr, '_is_master', side_effect=[True, False]):
-
                 self.assertIsNone(solr.is_replication_enabled())
-
-                with patch.object(solr, '_get_none_or_value',
-                                  return_value=None):
-                    with patch.object(solr, '_check_for_cores',
-                                      return_value=True):
-                        with patch.dict(solr.__opts__,
-                                        {'solr.cores':
-                                         MagicMock(return_value='A')}):
-                            with patch.object(solr, '_replication_request',
-                                              return_value='A'):
+                with patch.object(solr, '_get_none_or_value', return_value=None):
+                    with patch.object(solr, '_check_for_cores', return_value=True):
+                        with patch.dict(solr.__opts__, {'solr.cores': MagicMock(return_value='A')}):
+                            with patch.object(solr, '_replication_request', return_value='A'):
                                 self.assertDictEqual(solr.is_replication_enabled
                                                      (), {'A': 'a',
                                                           'errors': [error],
@@ -224,12 +214,9 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                     'warnings': 'warnings', 'data': 'data'}
 
         with patch.object(solr, '_get_return_dict', return_value={'A': 'a'}):
-            with patch.dict(solr.__opts__, {'solr.backup_path':
-                                            MagicMock(return_value='A'),
-                                            'solr.num_backups':
-                                            MagicMock(return_value='B'),
-                                            'solr.cores':
-                                            MagicMock(return_value=['A'])}):
+            with patch.dict(solr.__opts__, {'solr.backup_path': MagicMock(return_value='A'),
+                                            'solr.num_backups': MagicMock(return_value='B'),
+                                            'solr.cores': MagicMock(return_value=['A'])}):
                 with patch.object(os.path, 'sep', return_value='B'):
                     with patch.object(solr, '_get_none_or_value',
                                       side_effect=[None, True]):
@@ -237,16 +224,9 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                                           side_effect=[True, False]):
                             with patch.object(solr, '_replication_request',
                                               return_value=tempdict):
-
-                                with patch.dict(solr.__opts__,
-                                                {'solr.cores':
-                                                 MagicMock
-                                                 (return_value=['A'])}):
-                                    with patch.object(solr,
-                                                      '_update_return_dict',
-                                                      return_value='A'):
-                                        self.assertDictEqual(solr.backup(),
-                                                             {'A': 'a'})
+                                with patch.dict(solr.__opts__, {'solr.cores': MagicMock(return_value=['A'])}):
+                                    with patch.object(solr, '_update_return_dict', return_value='A'):
+                                        self.assertDictEqual(solr.backup(), {'A': 'a'})
 
                                 self.assertDictEqual(solr.backup(), tempdict)
 
@@ -286,31 +266,21 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
         '''
         Test to sets the master to ignore poll requests from the slaves.
         '''
-        with patch.object(solr, '_is_master', side_effect=[False, True, True,
-                                                           True]):
+        with patch.object(solr, '_is_master',
+                          side_effect=[False, True, True, True]):
             with patch.object(solr, '_get_none_or_value',
                               side_effect=[None, None, True, True, True]):
-                with patch.object(solr,
-                                  '_get_return_dict',
+                with patch.object(solr, '_get_return_dict',
                                   side_effect=[{'A': 'a'}, {}]):
                     with patch.object(solr, '_replication_request',
                                       return_value='A'):
-
-                        self.assertDictEqual(solr.set_replication_enabled('s'),
-                                             {'A': 'a'})
-
+                        self.assertDictEqual(solr.set_replication_enabled('s'), {'A': 'a'})
                         with patch.object(solr, '_check_for_cores',
                                           return_value=True):
-                            with patch.dict(solr.__opts__,
-                                            {'solr.cores':
-                                             MagicMock(return_value='n')}):
-                                self.assertEqual(solr.set_replication_enabled
-                                                 ('s'), {})
-
+                            with patch.dict(solr.__opts__, {'solr.cores': MagicMock(return_value='n')}):
+                                self.assertEqual(solr.set_replication_enabled('s'), {})
                         self.assertEqual(solr.set_replication_enabled('s'), 'A')
-
-                        self.assertEqual(solr.set_replication_enabled(False),
-                                         'A')
+                        self.assertEqual(solr.set_replication_enabled(False), 'A')
 
     def test_signal(self):
         '''
@@ -336,16 +306,11 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                                       return_value='A'):
                         with patch.object(solr, '_http_request',
                                           return_value='A'):
-                            with patch.dict(solr.__opts__,
-                                            {'solr.cores':
-                                             MagicMock(return_value='n')}):
-
+                            with patch.dict(solr.__opts__, {'solr.cores': MagicMock(return_value='n')}):
                                 self.assertIsNone(solr.reload_core())
-
                                 self.assertDictEqual(solr.reload_core(),
                                                      {'A': 'a', 'errors': error,
                                                       'success': False})
-
                                 self.assertEqual(solr.reload_core(), 'A')
 
     def test_core_status(self):
@@ -365,11 +330,8 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                         with patch.object(solr, '_http_request',
                                           return_value='A'):
                             with patch.dict(solr.__opts__,
-                                            {'solr.cores':
-                                             MagicMock(return_value='n')}):
-
+                                            {'solr.cores': MagicMock(return_value='n')}):
                                 self.assertIsNone(solr.core_status())
-
                                 self.assertDictEqual(solr.core_status(),
                                                      {'A': 'a', 'errors': error,
                                                       'success': False})
@@ -391,15 +353,9 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                                           return_value='A'):
                             with patch.object(solr, '_http_request',
                                               return_value='A'):
-
-                                self.assertDictEqual(solr.reload_import_config
-                                                     ('h'), {'A': 'a'})
-
-                                self.assertDictEqual(solr.reload_import_config
-                                                     ('h'), {'A': 'a'})
-
-                                self.assertEqual(solr.reload_import_config('h'),
-                                                 'A')
+                                self.assertDictEqual(solr.reload_import_config('h'), {'A': 'a'})
+                                self.assertDictEqual(solr.reload_import_config('h'), {'A': 'a'})
+                                self.assertEqual(solr.reload_import_config('h'), 'A')
 
     def test_abort_import(self):
         '''
@@ -416,13 +372,8 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                                           return_value='A'):
                             with patch.object(solr, '_http_request',
                                               return_value='A'):
-
-                                self.assertDictEqual(solr.abort_import('h'),
-                                                     {'A': 'a'})
-
-                                self.assertDictEqual(solr.abort_import('h'),
-                                                     {'A': 'a'})
-
+                                self.assertDictEqual(solr.abort_import('h'), {'A': 'a'})
+                                self.assertDictEqual(solr.abort_import('h'), {'A': 'a'})
                                 self.assertEqual(solr.abort_import('h'), 'A')
 
     def test_full_import(self):
@@ -487,7 +438,5 @@ class SolrTestCase(TestCase, LoaderModuleMockMixin):
                                       return_value='A'):
                         with patch.object(solr, '_http_request',
                                           return_value='A'):
-                            self.assertDictEqual(solr.import_status('h'),
-                                                 {'A': 'a'})
-
+                            self.assertDictEqual(solr.import_status('h'), {'A': 'a'})
                             self.assertEqual(solr.import_status('h'), 'A')
