@@ -4,7 +4,7 @@
 '''
 
 # Import Python Libs
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals, print_function
 
 # Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
@@ -19,6 +19,9 @@ from tests.support.mock import (
 # Import Salt Libs
 import salt.states.network as network
 
+import logging
+log = logging.getLogger(__name__)
+
 
 class MockNetwork(object):
     '''
@@ -115,12 +118,6 @@ class NetworkTestCase(TestCase, LoaderModuleMockMixin):
                                                                          False),
                                                          ret)
 
-                    ret.update({'changes': {'interface':
-                                            '--- \n+++ \n@@ -1 +1 @@\n-A\n+B'},
-                                'result': False,
-                                'comment': "'ip.down'"})
-                    self.assertDictEqual(network.managed('salt', 'stack'), ret)
-
     def test_routes(self):
         '''
             Test to manage network interface static routes.
